var validator = require("Validator");
var { default: localizify } = require("localizify");
var en = require("../language/en");
var fr = require("../language/fr");
var { t } = require("localizify");

var cryptoLib = require("cryptlib");
var shakey = cryptoLib.getHashSha256(process.env.KEY, 32);

var connection = require("../config/database");

var bypassMethods = new Array(
  "uploadimage",
  "validate_user",
  "signup",
  "login",
  "verify_otp",
  "resend_otp",
  "forgot_password",
  "set_password",
  "reset_password",
  "verifyotp",
  "getCountryCode"
);
var bypassKeyMethod = new Array(
  "forgot_password",
  "set_password",
  "reset_password"
);

var middleware = {
  checkValidationRules: function (res, request, rules, message) {
    var v = validator.make(request, rules, message);
    //console.log(request, rules, message);
    // console.log(v);
    if (v.fails()) {
      var errors = v.getErrors();
      //console.log(errors);
      var error = "";
      for (var key in errors) {
        error = errors[key][0];
        break;
      }
      response_data = {
        code: "0",
        message: error,
      };
      res.status(200);
      res.send(response_data);
      console.log("respone", response_data);
      return false;
    } else {
      return true;
    }
  },

  send_response: function (req, res, code, message, data) {
    this.getmessage(req.lang, message, function (translated_message) {
      if (data == null) {
        response_data = {
          code: code,
          message: translated_message,
        };
        // res.status(200);
        // res.send(response_data);
        middleware.encryption(response_data, function (response) {
          res.status(200);
          res.send(response);
        });
      } else {
        response_data = {
          code: code,
          message: translated_message,
          data: data,
        };
        // res.status(200);
        //   res.send(response_data);
        middleware.encryption(response_data, function (response) {
          res.status(200);
          res.send(response);
        });
      }
    });
  },

  getmessage: function (language, message, callback) {
    localizify.add("en", en).add("fr", fr).setLocale(language);

    callback(t(message.keyword, message.content));
  },

  extractHeaderLanguage: function (req, res, callback) {
    var headerlang =
      req.headers["accept-language"] != undefined &&
      req.headers["accept-language"] != ""
        ? req.headers["accept-language"]
        : "en";

    req.lang = headerlang;
    req.language = headerlang == "en" ? en : fr;
    localizify.add("en", en).add("fr", fr).setLocale(headerlang);

    callback();
  },

  // -------------------------API KEY---------------------------
  validateApikey: function (req, res, callback) {
    var api_key =
      req.headers["api-key"] != undefined && req.headers["api-key"] != ""
        ? req.headers["api-key"]
        : "";

    var path_data = req.path.split("/");

    if (bypassKeyMethod.indexOf(path_data[4]) === -1) {
      if (api_key != "") {
        try {
          var dec_apikey = cryptoLib.decrypt(api_key, shakey, process.env.IV);
          //console.log("key",dec_apikey);
          if (dec_apikey != "" && dec_apikey == process.env.API_KEY) {
            callback();
          } else {
            response_data = {
              code: "0",
              message: "invalid Api key",
            };
            middleware.encryption(response_data, function (response) {
              res.status(401);
              res.send(response);
            });
          }
        } catch (error) {
          response_data = {
            code: "0",
            message: "invalid Api key",
          };
          middleware.encryption(response_data, function (response) {
            res.status(401);
            res.send(response);
          });
        }
      } else {
        response_data = {
          code: "0",
          message: "invalid Api key",
        };
        middleware.encryption(response_data, function (response) {
          res.status(401);
          res.send(response);
        });
      }
    } else {
      callback();
    }
  },

  // ----------------VALIDATE TOKEN----------------------
  validateHeaderToken: function (req, res, callback) {
    var headertoken =
      req.headers["token"] != undefined && req.headers["token"] != ""
        ? req.headers["token"]
        : "";
    //console.log(headertoken);
    //Logic
    var path_data = req.path.split("/");
    if (bypassMethods.indexOf(path_data[4]) === -1) {
     // console.log("1");
      if (headertoken != "") {
        try {
          // console.log("2");
          var dec_token = cryptoLib.decrypt(
            headertoken,
            shakey,
            process.env.IV
          );
         // console.log(dec_token);
          if (dec_token != "") {
            connection.query(
              "select * from tbl_user_device where token = ?",
              [dec_token],
              function (error, result) {
                //console.log("result", result);
                //console.log("result", error);
                if (!error && result.length > 0) {
                  //req.user_id = result[0].id;
                  req.user_id = result[0].user_id;
                  console.log();
                  callback();
                } else {
                  response_data = {
                    code: "0",
                    message: "invalid token provided ",
                  };
                  middleware.encryption(response_data, function (response) {
                    res.status(401);
                    res.send(response);
                  });
                }
              }
            );
          } else {
            response_data = {
              code: "0",
              message: "invalid token provided",
            };
            middleware.encryption(response_data, function (response) {
              res.status(401);
              res.send(response);
            });
          }
        } catch (error) {
          response_data = {
            code: "0",
            message: "invalid token provided",
          };
          middleware.encryption(response_data, function (response) {
            res.status(401);
            res.send(response);
          });
        }
      } else {
        response_data = {
          code: "0",
          message: "invalid token provided",
        };
        middleware.encryption(response_data, function (response) {
          res.status(401);
          res.send(response);
        });
      }
    } else {
      callback();
    }
  },

  // --------------------------decryption------------------------
  decryption: function (encrypted_text, callback) {
    //console.log(encrypted_text);
    if (
      encrypted_text != undefined &&
      Object.keys(encrypted_text).length !== 0
    ) {
      //console.log('hiii');
      try {
        var request = JSON.parse(
          cryptoLib.decrypt(encrypted_text, shakey, process.env.IV)
        );
        // console.log("/////////",request);
        callback(request);
      } catch (error) {
        callback({});
      }
    } else {
      callback({});
    }
  },

  // ---------------------------ENCRYPTION------------------------
  encryption: function (response_data, callback) {
    //console.log(response_data);

    var response = cryptoLib.encrypt(
      JSON.stringify(response_data),
      shakey,
      process.env.IV
    );
    callback(response);
  },
  
    //------------------------- update today task ----------------------------
  updateTodayTask: function () {
    //console.log("hello everyone");
    connection.query(
      `UPDATE tbl_user SET today_contact=0 WHERE is_deleted=0`,
      function (error, result) {
        if (!error) {
          console.log("done cron");
        } else {
          console.log("fail cron");
        }
      }
    );
  },
  
};
module.exports = middleware;
