var express = require("express");
const connection = require("../../../config/database");
var Validator = require("Validator");
var router = express.Router();
var middleware = require("../../../middleware/validator");
const auth = require("./auth_model");
var multer = require("multer");
var path = require("path");
var { request } = require("http");


// -------------------SIGNUP---------------------------

router.post("/signup", function (req, res) {
  //console.log(req.body);
  middleware.decryption(req.body, function (request) {
    //console.log("req", request);

    var rules = {
      name: "required",
      country_code_id: "required",
      phone_number: "required",
      email: "required|email",
      password: "required",
      device_name: "",
      device_token: "required",
      device_type: "required|in:a,i,w",
      os_version: "",
      app_version: "",
    };

    var message = {
      required: req.language.required,
      email: req.language.email,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      auth.signup(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

// --------------------LOGIN--------------------------------------
router.get("/login", function (req, res) {
  // var request = req.body;
  middleware.decryption(req.body, function (request) {
    //console.log("=====", request);

    var rules = {
      email: "required|email",
      password: "required",
      device_name: "",
      device_token: "required",
      device_type: "required",
      os_version: "",
      app_version: "",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      auth.login(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

// ------------------ FORGOT PASSWORD -----------------------------
router.post("/forgot_password", function (req, res) {
  // var request = req.body;
  // var email = req.body.email;
  middleware.decryption(req.body, function (request) {
    var rules = {
      email: "required|email",
    };

    var message = {
      required: req.language.required_message,
      email: "please enter valid email",
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      auth.forgotPassword(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});

//================== Set Password =================================

router.post("/set_password", function (req, res) {
  middleware.decryption(req.body, function (request) {
    console.log(request);
    var rules = {
      email: "required|email",
      new_password: "required",
    };

    var message = {
      required: req.language.required_message,
      email: "please enter valid email",
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      auth.reset_password(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============================= Change Password ===================
router.post("/changePassword", function (req, res) {
  middleware.decryption(req.body, function (request) {
    //console.log("req",request);
    // console.log("test");
    var rules = {
      old_password: "required",
      new_password: "required",
    };
    const message = {
      required: req.language.required,
    };
    //console.log(request)

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      auth.changepassword(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============================= User Profile ======================
router.get("/userprofile", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    auth.getUserDetails(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

// ---------------------------- LOGOUT ----------------------------
router.post("/logout", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    auth.logout(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//----------------------------verify otp---------------------------
router.post("/verifyotp", function (req, res) {
  // console.log(req.body);
  middleware.decryption(req.body, function (request) {
    console.log(request);

    var rules = {
      email: "required",
      otp: "required",
    };
    const message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      auth.otpVerify(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//------------------------delete user account----------------------
router.post("/deleteuser", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    auth.deleteUser(request, function (code, message, data) {
      middleware.send_response(res, req, code, message, data);
    });
  });
});

//----------------------- Update Profile --------------------------
router.post("/updateprofile", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    var rules = {
      name: "required",
      country_code_id: "required",
      phone_number: "required",
      profile_image: "",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      request.user_id = req.user_id;
      auth.updateProfile(request, function (code, message, data) {
        middleware.send_response(res, req, code, message, data);
      });
    }
  });
});

//===================== Get Country Code ======================

router.get("/getCountryCode", function (req, res) {
  middleware.decryption(req.body, function (request) {
    auth.getCountryCode(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
    });
  });
});


module.exports = router;
