var express = require("express");
const connection = require("../../../config/database");
var Validator = require("Validator");
var router = express.Router();
var middleware = require("../../../middleware/validator");
const userModel = require("./user_model");
var multer = require("multer");
var path = require("path");
var { request } = require("http");




// ========================= Total Contact ==============================

router.get("/totalCount", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.totalcount(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//============================ Total Contacts====================================
router.get("/contactListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      filter_id: "",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contacts(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============================ Total Followup====================================
router.get("/followupListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      filter_id: "",
    };
    var message = {
      required: req.language.required,
    };
    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.followups(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============================ Total Meetings ===================================
router.get("/meetingListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      filter_id: "",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.meetings(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//=========================== Total Reconnects ==================================
router.get("/reconnectListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.reconnects(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//========================== All Contact Type listing ==========================
router.get("/contactType", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.contactType(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});
//------------------------------------------------------------------------------
// ---------------- All notes add------------------
router.post("/addNotes", function (req, res) {
  //console.log("contact",req.body);
  middleware.decryption(req.body, function (request) {
    //console.log("contact id",request);
    var rules = {
      label_id: "required",
      contact_id: "required",
      notes: "required",
      file: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addNotes(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//------------------------------------------------------------------------------
//========================== Add Followup Notes ================================
router.post("/addFollowupNote", function (req, res) {
  //console.log("contact",req.body);
  middleware.decryption(req.body, function (request) {
    //console.log("contact id",request);
    var rules = {
      followup_id: "required",
      notes: "required",
      file: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addFollowupNotes(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//=========================== Add Followup =======================================
router.post("/addFollowup", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
      notes: "",
      file: "",
      date: "required",
      time: "",
      timezone_id: "",
      is_repeat: "required",
      repeat: "",
      custom_date: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addFollowup(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});
//========================== Delete Followup ===================================
router.post("/deleteFollowup", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      followup_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.deleteFollowup(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});

//======================= Add Meeting Notes ====================================
router.post("/addMeetingNote", function (req, res) {
  middleware.decryption(req.body, function (request) {
    //console.log("contact", request);

    var rules = {
      meeting_id: "required",
      notes: "required",
      file: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addMeetingNotes(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//======================= Add Reconnect  ====================================
router.post("/addReconnectsNotes", function (req, res) {
  middleware.decryption(req.body, function (request) {
    console.log("contact", request);

    var rules = {
      contact_id: "required",
      notes: "required",
      file: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addReconnectsNotes(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//======================= Add Meeting ====================================
router.post("/addMeeting", function (req, res) {
  middleware.decryption(req.body, function (request) {
    //console.log("contact", request);

    var rules = {
      contact_id: "required",
      notes: "required",
      file: "",
      date: "required",
      start_time: "required",
      end_time: "required",
      link: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addMeeting(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//======================= Delete Meeting =======================================
router.post("/deleteMeeting", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      meeting_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.deleteMeeting(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});

//====================== Add New Contact Type =================================
router.post("/addNewType", function (req, res) {
  middleware.decryption(req.body, function (request) {
    // console.log(request);
    var rules = {
      name: "required",
      color: "required",
    };

    var message = {
      required: req.language.required,
    };
    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addNewType(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});

//====================== Rename Contact Type ==================================
router.post("/renameType", function (req, res) {
  middleware.decryption(req.body, function (request) {
    // console.log(request);
    var rules = {
      id: "required",
      name: "required",
    };

    var message = {
      required: req.language.required,
    };
        request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.renameType(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});

//====================== Delete Contact Type ==================================
router.post("/deleteType", function (req, res) {
  middleware.decryption(req.body, function (request) {
    // console.log(request);
    var rules = {
      id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.deleteType(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});

//===================== filter level wise ====================================
router.post("/filteLevel", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      level: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.filteLevel(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//==================== Filter Contact =======================================
router.get("/getAllContacts", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;

    userModel.getAllContacts(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//=================== Add Contact ==========================================
router.post("/addContact", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      firstname: "required",
      lastname: "required",
      email: "required",
      country_code: "required",
      phone_number: "required",
      type: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addContact(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Delete Contact ================================
router.post("/deleteContact", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.deleteContact(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//=================== View Contact Details==================================
router.post("/viewContact", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.viewContactDetails(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//================== Update Contact Details =============================
router.post("/updateContact", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
      firstname: "required",
      lastname: "required",
      email: "required",
      country_code_id: "required",
      phone_number: "required",
      type: "required",
      compnay_name: "",
      alternate_email: "",
      additional_phone_number: "",
      profile_image: "",
      hashtags: "",
      address: "",
      contact_method: "",
      timezone_id: "",
      language_id: "",
      level: "",
      last_update: "",
      social_media_id: "",
      social_media_link: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.updateContactDetails(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//================== Notification Listing ===============================
router.get("/notificationListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.notificationListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//================= Language Listing ====================================
router.get("/languageListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.languageListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//================= Social Media Listing ================================
router.get("/socialMediaListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.socialMediaListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//=================== contact social media list ==============================
router.post("/contactSocialMedia", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contactSocialMedia(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});
//================ Time Zone ============================================
router.post("/timeZoneListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.timeZoneListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//================ Recent/Hight Frequent / Low Frequent / Reconnect Contact ======
router.post("/contactsFiltering", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      filter_no: "",
    };

    var message = {
      required: req.language.required,
    };
        request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contactsFiltering(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Team Listing =========================================
router.get("/teamListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      search: "",
    };

    var message = {
      required: req.language.required,
    };
    request.user_id = req.user_id;
    
    if (middleware.checkValidationRules(res, request, rules, message)) {
    userModel.teamListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
    }
  });
});

//================== all teams ==========================================
router.get("/allTeamListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.allTeamListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//============== Team Goal ==================================================
router.get("/teamGoal", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      to_date: "",
      from_date: "",
      team_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.teamGoal(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});


//============== Teammate Task ==============================================
router.get("/teammateTask", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      teammate_id: "required",
      team_id: "required",
      date: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.teammateTask(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});


//======================== Teammmate Date wise data =================
router.post("/teammateDateTask", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      teammate_id: "required",
      date: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.teammateDateTask(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

  //============== Delete Team member ========================================
router.get("/deleteTeamMember", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      teammate_id: "required",
      team_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.deleteTeamMember(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});
//============== Team Member Listing =================================
router.get("/teamMembers", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      team_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.teamMembers(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Create New Team ======================================
router.post("/createTeam", function (req, res) {
  middleware.decryption(req.body, function (request) {
    // console.log(request);
    var rules = {
      team_name: "",
      team_profile: "",
      member_id: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.creatTeam(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Join Team ===========================================
router.post("/joinTeam", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      team_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.joinTeam(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//=========== leave Team ==============================================
router.post("/leaveTeam", function (req, res) {
  middleware.decryption(req.body, function (request) {
    //  console.log(request);

    var rules = {
      team_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.leaveTeam(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//========== all Bloglisting ===========================================
router.get("/allBloglisting", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.allBloglisting(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//========== View Blog ================================================
router.get("/viewBlog", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      blog_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.viewBlog(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});
//============= all Chatavirsity ======================================
router.get("/allChatavirsity", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.allChatavirsity(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//============= View Chatavirsity =====================================
router.get("/viewChatavirsity", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      chatavirsity_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.viewChatavirsity(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============= All Faq's ============================================
router.post("/allFaqs", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.allFaqs(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//=========== search Faq ============================================
router.post("/searchFaq", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      search: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.searchFaq(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//========== Contact Us ============================================
router.post("/contactUs", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      fullname: "required",
      phone_number: "required",
      description: "required",
    };

    var message = {
      required: req.language.required,
    };
    
    request.user_id = req.user_id;
    
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contactUs(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//======================= Search By Hashtag ======================================
router.get("/searchHashtag", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      search: "required",
    };
    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.searchHashTag(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//======================= Search Contact =======================================
router.get("/searchContact", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      search: "required",
    };
    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.searchContact(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//=================== Search Blog =============================================
router.get("/searchBlog", function (req, res) {
  // console.log(req.body);
  middleware.decryption(req.body, function (request) {
    //console.log(request);
    var rules = {
      search: "required",
    };
    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.searchBlog(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//=================== Chatavirsity Blog =======================================
router.get("/searchChatavirsity", function (req, res) {
  middleware.decryption(req.body, function (request) {
    console.log(request);
    var rules = {
      search: "required",
    };
    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.searchChatavirsity(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//================== Add Daily Plan ===========================================
router.post("/addDailyPlan", function (req, res) {
  middleware.decryption(req.body, function (request) {
    console.log(request);
    var rules = {
      title: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addDailyPlan(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//================== Daily Plan Listing ========================================
router.get("/dailyPlanListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.dailyPlanListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//================== Delete Daily Plan ========================================
router.get("/deleteDailyPlan", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      plan_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.deleteDailyPlan(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});
//================== Update Daily Plan ========================================
router.post("/updateDailyPlan", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      title: "required",
      plan_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.updateDailyPlan(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//================== complete Daily Plan ========================================
router.post("/completeDailyPlan", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      plan_id: "required",
      is_completed: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.completeDailyPlan(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});
//=============== Chat Log ===========================================
router.post("/addChatlog", function (req, res) {
  middleware.decryption(req.body, function (request) {
    console.log(request);
    var rules = {
      contact_id: "required",
      notes: "required",
      file: "",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addChatlog(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== sheduled listing ================================
router.get("/sheduledListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
       date: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.sheduledListing(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Logged Connections ============================
router.get("/loggedConnections", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      filter_no: "",
      date: "",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.loggedConnections(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Delete Logged chat============================================
router.get("/deleteLogged", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      label: "required",
      contact_id: "required",
      followup_id: "",
      meeting_id: "",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.deleteLogged(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== level =======================================================
router.get("/levelIncrease", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.levelIncrease(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Genarate team link ========================================== router only for test
router.post("/generateTeamLink", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      team_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.generateTeamLink(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Complete Follow up ======================================
router.post("/completeFollowup", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      followup_id: "required",
      is_completed: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.completeDailyPlan(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Complete Meeting ======================================
router.post("/completeMeeting", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      meeting_id: "required",
      is_completed: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.completeMeeting(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Other Teams ==============================================
router.get("/otherteams", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.otherteams(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//======================== User Notes===============================
router.post("/userNote", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      user_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.userNote(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//======================== User Notes Details ===============================
router.get("/userNoteDetails", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      user_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.userNoteDetails(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Complete Meeting Note and File ========================================
router.post("/completeMeetingNote", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      meeting_id: "required",
      note: "required",
      file: "",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.completeMeetingNote(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Complete Followup Note and File ========================================
router.post("/completeFollowupNote", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      followup_id: "required",
      note: "required",
      file: "",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.completeFollowupNote(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//=================== Add social media =======================================
router.post("/addContactSocialmedia", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
      social_media_id: "required",
      social_media_link: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addContactSocialmedia(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============ Update contact profile ================================
router.post("/updateContactProfile", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      profile_image: "required",
      contact_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.updateContactProfile(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============ View Contact Note =====================================
router.post("/contactNoteDetails", function (req, res) {
  //console.log(req);
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contactNoteDetails(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============ Save Contact Note =====================================

router.post("/saveContactNote", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      note: "required",
      contact_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.saveContactNote(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});


//============ add contact level ================================
router.post("/addContactLevel", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
      level: "required",
      hashtags: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addContactLevel(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============ add contact level ================================
router.post("/contactLogListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required"
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contactLogListing(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});


//============ add contact log file ================================
router.post("/addFileContactLog", function (req, res) {
  middleware.decryption(req.body, function (request) {

    var rules = {
      contact_id: "required",
      file: "required",
      followup_id: "",
      meeting_id: "",
      chatlog_id: "",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addFileContactLog(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============ update contact log file ================================
router.post("/updateNoteContactLog", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
      note: "required",
      followup_id: "",
      meeting_id: "",
      chatlog_id: "",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.updateNoteContactLog(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============ contact meeting listing ================================
router.post("/contactMeetingListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contactMeetingListing(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============ contact followup listing ================================
router.post("/contactFollowupListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contactFollowupListing(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//======================== teammate Private Note ====================
router.post("/teammatePrivateNote", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      teammate_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.teammatePrivateNote(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//========= teammate update private note ==========================
router.post("/teammatePrivateNoteUpdate", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      teammate_id: "required",
      note: "",
      file: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.teammatePrivateNoteUpdate(
        request,
        function (code, message, data) {
          middleware.send_response(request, res, code, message, data);
        }
      );
    }
  });
});

//============ Static Pages ================================
router.get("/staticPages", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.staticPages(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

  //============ search contact main searach bar ================================
 router.post("/searchContactMain", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      search: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.searchContactMain(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});
  
  
  //========= increse / descrise contacts count =========================
router.post("/contactCount", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      count: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contactCount(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
}); 

module.exports = router;
